@@ -1,5 +1,8 @@
 import numpy as np
-from scipy.integrate import cumtrapz
+from scipy.integrate import cumtrapz, odeint
+from scipy.integrate import cumtrapz, odeint
+
+from scipy.interpolate import interp1d
 from scipy.stats import norm
 
 from ..calc.cfc import CFC
@@ -217,6 +220,71 @@ class StandardFunction:
         """
         return 1 / (1 + np.exp(-k * (x - x0)))
 
+
+    @staticmethod
+    def ASI(time_:np.ndarray, acc_x:np.ndarray,
+            acc_y: np.ndarray, acc_z: np.ndarray,
+            limit_acc_x:float,
+            limit_acc_y:float,
+            limit_acc_z:float,
+            units):
+        """
+
+        :param time
+        :param acceleration_x:
+        :param acceleration_y:
+        :param acceleration_z:
+        :param limit_acceleration_x:
+        :param lim_acceleration_y:
+        :param lim_acceleration_z:
+        :return:
+        """
+        g = 9.81
+
+        # average over time
+        N = np.where(time_.flatten() / units.second() < 0.05)[0][-1]  # 50 ms
+        import matplotlib.pyplot as plt
+
+        plt.plot(acc_x)
+        plt.show()
+        acc_x /= units.meter() / (units.second() ** 2) * g # acc_x in [m/s^2]
+        acc_y /= units.meter() / (units.second() ** 2) * g # acc_y in [m/s^2]
+        acc_z /= units.meter() / (units.second() ** 2) * g # acc_z in [m/s^2]
+        acceleration_x_average = np.convolve(acc_x.flatten(), np.ones(N) / N, mode='same').reshape(-1, 1)
+        acceleration_y_average = np.convolve(acc_y.flatten(), np.ones(N) / N, mode='same').reshape(-1, 1)
+        acceleration_z_average = np.convolve(acc_z.flatten(), np.ones(N) / N, mode='same').reshape(-1, 1)
+
+        from scipy import signal
+        sos = signal.butter(2, 13, 'lowpass', fs=1000, output='sos')
+        acceleration_x_butter = signal.sosfilt(sos, acc_x.flatten()).reshape(-1, 1)
+        acceleration_y_butter = signal.sosfilt(sos, acc_y.flatten()).reshape(-1, 1)
+        acceleration_z_butter = signal.sosfilt(sos, acc_z.flatten()).reshape(-1, 1)
+        #acceleration_y_butter = np.convolve(acc_y.flatten(), np.ones(N) / N, mode='same').reshape(-1, 1)
+        #acceleration_z_butter = np.convolve(acc_z.flatten(), np.ones(N) / N, mode='same').reshape(-1, 1)
+
+        plt.plot(acc_x)
+        plt.plot(acceleration_x_average)
+        plt.plot(acceleration_x_butter)
+        plt.show()
+
+        return np.sqrt((acceleration_x_butter/limit_acc_x)**2
+                       + (acceleration_y_butter/limit_acc_y)**2
+                        + (acceleration_z_butter/limit_acc_z)**2)
+
+    @staticmethod
+    def ccdf_normal_dist(x: float, mean: float, standard_deviation: float, units):
+        """
+
+        :param x:
+        :param mean:
+        :param standard_deviation:
+        :return:
+
+        https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.norm.html
+        """
+        return norm.cdf(x, loc=mean, scale=standard_deviation)
+
+
     @staticmethod
     def cfc(time: np.ndarray, sampled_array: np.ndarray, cfc: int, units, mirroring: bool = False):
         """
@@ -274,6 +342,8 @@ class StandardFunction:
 
         return ti
 
+
+
     @staticmethod
     def NIC(a_t1: np.ndarray, a_head: np.ndarray, time_: np.ndarray, units):
         """
@@ -297,6 +367,69 @@ class StandardFunction:
 
         return np.array(return_value_nic).reshape(-1, 1)
 
+    @staticmethod
+    def DAMAGE(time: np.array, ra_x:np.array, ra_y:np.array, ra_z:np.array, mx: float, my: float, mz: float,
+               kxx: float, kyy: float, kzz: float, kxy: float, kyz: float, kxz: float, a0: float, a1: float, beta: float,
+               units):
+
+        def stiffness_matrix(kxx, kyy, kzz, kxy, kyz, kxz):
+            return np.array([[kxx + kxy + kxz, -kxy, -kxz],
+                             [-kxy, kxy + kyy + kyz, -kyz],
+                             [-kxz, -kyz, kxz + kyz + kzz]])
+
+        def damping_matrix(m, k, a0, a1):
+            return a0 * m + a1 * k
+
+        def create_matrices(mx, my, mz, kxx, kyy, kzz, kxy, kyz, kxz, a0, a1):
+            m = np.diag([mx, my, mz])
+            k = stiffness_matrix(kxx, kyy, kzz, kxy, kyz, kxz)
+            c = damping_matrix(m, k, a0, a1)
+            return m, c, k
+
+        def equation_of_motion(y, t, m, m_inv, c, k, f_a_x, f_a_y, f_a_z):
+            delta_x, delta_y, delta_z, d_delta_x, d_delta_y, d_delta_z = y
+            delta = np.array([delta_x, delta_y, delta_z])
+            d_delta = np.array([d_delta_x, d_delta_y, d_delta_z])
+
+            a = np.array([f_a_x(t), f_a_y(t), f_a_z(t)])
+            dd_delta = np.dot(m_inv, np.dot(m, a) - (np.dot(c, d_delta) + np.dot(k, delta)))
+            dydt = [d_delta_x, d_delta_y, d_delta_z, dd_delta[0], dd_delta[1], dd_delta[2]]
+            return dydt
+
+        # initial values of delta and delta' are zero
+        t = time.flatten() / units.second()
+        ra_x = ra_x.flatten() / (1 / (units.second() ** 2))   # to [rad/s^2]
+        ra_y = ra_y.flatten() / (1 / (units.second() ** 2))   # to [rad/s^2]
+        ra_z = ra_z.flatten() / (1 / (units.second() ** 2))   # to [rad/s^2]
+
+        y0 = [0.0, 0.0, 0.0, 0.0, 0.0, 0.0]
+        m, c, k = create_matrices(mx, my, mz, kxx, kyy, kzz, kxy, kyz, kxz, a0, a1)
+
+        m_inv = np.linalg.inv(m)
+        # since mass matrix is identity matrix with parameters from settings file this could be considered in the
+        # calculation if speed is an issue
+
+        f_a_x = interp1d(t, ra_x, fill_value='extrapolate')
+        f_a_y = interp1d(t, ra_y, fill_value='extrapolate')
+        f_a_z = interp1d(t, ra_z, fill_value='extrapolate')
+        sol = odeint(equation_of_motion, y0, t,
+                     args=(m, m_inv, c, k, f_a_x, f_a_y, f_a_z))
+
+        # alternative solution for faster execution (but less precise):
+        #
+        # sol = solve_ivp(equation_of_motion, (time_ang_acc[0], time_ang_acc[-1]), y0, method='RK45', t_eval=time_ang_acc,
+        #                  args=(m, m_inv, c, k, time_ang_acc, ang_acc_x, ang_acc_y, ang_acc_z))
+        #     print(ptime.time() - t_start)
+        #     delta = sol['y'][:3, :]
+        #     delta_norm = np.linalg.norm(delta, axis=0)
+
+        delta = sol[:, :3]
+        delta_norm = np.linalg.norm(delta, axis=1)
+        damage = beta * np.max(delta_norm)
+
+        return damage
+
+
     @staticmethod
     def HIC(time: np.ndarray, a_res: np.ndarray, units, nidx):
         """
@@ -926,17 +1059,17 @@ class StandardFunction:
         nij = np.zeros(shape=(len(force_z)))
         temp_n_value = np.zeros(shape=(4,))
 
-        mtot = moment_y - moc_d * force_x
+        moc = moment_y - moc_d * force_x
 
         for o in range(len(force_z)):
             # NCF
-            temp_n_value[0] = force_z[o] / nij_fzc_co + mtot[o] / nij_myc_fl if force_z[o] <= 0 and mtot[o] > 0 else 0
+            temp_n_value[0] = force_z[o] / nij_fzc_co + moc[o] / nij_myc_fl if force_z[o] <= 0 and moc[o] > 0 else 0
             # NCE
-            temp_n_value[1] = force_z[o] / nij_fzc_co + mtot[o] / nij_myc_ex if force_z[o] <= 0 and mtot[o] <= 0 else 0
+            temp_n_value[1] = force_z[o] / nij_fzc_co + moc[o] / nij_myc_ex if force_z[o] <= 0 and moc[o] <= 0 else 0
             # NTF
-            temp_n_value[2] = force_z[o] / nij_fzc_te + mtot[o] / nij_myc_fl if force_z[o] > 0 and mtot[o] > 0 else 0
+            temp_n_value[2] = force_z[o] / nij_fzc_te + moc[o] / nij_myc_fl if force_z[o] > 0 and moc[o] > 0 else 0
             # NTE
-            temp_n_value[3] = force_z[o] / nij_fzc_te + mtot[o] / nij_myc_ex if force_z[o] > 0 and mtot[o] <= 0 else 0
+            temp_n_value[3] = force_z[o] / nij_fzc_te + moc[o] / nij_myc_ex if force_z[o] > 0 and moc[o] <= 0 else 0
 
             nij[o] = np.max(temp_n_value)
             temp_n_value = np.zeros(shape=(4,))
