@@ -162,17 +162,28 @@ class BinoutData(object):
         initialized
         :param elem_name:  only necessary for LS-dyna elout data
         """
-        if elem_name is not None:
+        if elem_name is not None and self._name=="elout":
             self._time = self._binout.read(self._name, elem_name, 'time').flatten()
             self._time_interp = self._interp_time(self._time)
             self._ids = np.array(self._binout.read(self._name, elem_name, self.__class__.ids_name)[0])
+            try:
+                len(self._ids)
+            except TypeError:
+                # case if beam data sequence consists only of one element!
+                self._ids = np.array([self._ids])
             self._read_data_types(elem_name=elem_name)
         else:
-            self._time = self._binout.read(self._name, 'time').flatten()
-            self._time_interp = self._interp_time(self._time)
-            # TODO: Check if data is not there index out of range -> resulting crash
-            self._ids = np.array(self._binout.read(self._name, self.__class__.ids_name))
-            self._read_data_types()
+            if self._name == "jntforc":
+                self._time = self._binout.read(self._name, elem_name, 'time').flatten()
+                self._time_interp = self._interp_time(self._time)
+                self._ids = np.array(self._binout.read(self._name, elem_name, self.__class__.ids_name))
+                self._read_data_types(elem_name=elem_name)
+            else:
+                self._time = self._binout.read(self._name, 'time').flatten()
+                self._time_interp = self._interp_time(self._time)
+            #    TODO: Check if data is not there index out of range -> resulting crash
+                self._ids = np.array(self._binout.read(self._name, self.__class__.ids_name))
+                self._read_data_types()
 
         assert (len(self._ids.shape) == 1)
 
@@ -265,6 +276,10 @@ class BinoutData(object):
             elem_name = "beam"
             elements = self._binout.read(self._name, elem_name)
 
+        if self._name == "jntforc":
+            elem_name = "joints"
+            elements = self._binout.read(self._name, elem_name)
+
         # check if required data is available (defined in SBTout.__DATA_CHANNEL_TYPES__)
         if not self._check_negative_intersection(elements):
             return False
@@ -284,6 +299,8 @@ class BinoutData(object):
             return_function = self._check_id_in_binout("_cross_sections")
         elif self._name == "nodout":
             return_function = self._check_id_in_binout("_node")
+        elif self._name == "jntforc":
+            return_function = self._check_id_in_binout("_jntforc")
         elif self._name == "rcforc":
             return_function = self._check_id_in_binout("_contact")
         elif self._name == "deforc":
@@ -302,6 +319,8 @@ class BinoutData(object):
             return_function = self._check_id_in_binout("_energy_global")
         elif self._name == "abstat":
             return_function = self._check_id_in_binout("_abstat")
+        elif self._name == "abstat_cpm":
+            return_function = self._check_id_in_binout("_abstat_cpm")
         if not return_function[0]:
             self._logger.emit(LOGConstants.WARNING[0], "Not valid ID: " + return_function[1] +
                               ". Plese check your def file!")
@@ -324,6 +343,9 @@ class BinoutData(object):
             # keys = self._binout.read(self._name)
             # ids_list = np.concatenate([self._binout.read(self._name, elem_name, "ids")[0] if elem_name != "solid" else
             #                           self._binout.read(self._name, elem_name, "ids") for elem_name in keys])
+        elif self._name == "jntforc":
+            ids_list = self._binout.read(self._name, "joints", self.ids_name)
+
         else:
             ids_list = self._binout.read(self._name, self.ids_name)
 
@@ -380,7 +402,7 @@ class BinoutData(object):
         if len(ids) == 0:
             if "ID" in json_object:
                 self._logger.emit(LOGConstants.ERROR[0],
-                                  "Missing ID in the input data with identifier: " + json_object["ID"])
+                                  "Missing ID in binary input data, identifier: " + json_object["ID"])
 
             return
 
