@@ -972,6 +972,7 @@ class Elout(BinoutData):
         """
         BinoutData.__init__(self, binout, logger, dynasaur_definitions, 'elout')
 
+
 class Abstat(BinoutData):
     # applies for beam elements!
     DATA_CHANNEL_TYPES = ['dm_dt_out', 'pressure', 'internal_energy', 'density', 'surface_area', 'dm_dt_in', 'dm_dt_outp',
@@ -992,6 +993,26 @@ class Abstat(BinoutData):
         BinoutData.__init__(self, binout, logger, dynasaur_definitions, 'abstat')
 
 
+class AbstatCPM(BinoutData):
+    # applies for beam elements!
+    DATA_CHANNEL_TYPES = ['dm_dt_out', 'pressure', 'internal_energy', 'density', 'surface_area', 'dm_dt_in',
+                          'inflator_e', 'reaction', 'volume', 'gas_temp', 'total_mass', 'pres_particle', 'Trans_ke']
+
+    ids_name = "ids"
+
+    def __init__(self, binout, logger, dynasaur_definitions):
+        """
+        Initialization i.e. call BinoutData constructor
+
+        :param: binout
+        :param: logger
+        :param: dynasaur definition
+
+        :return:
+        """
+        BinoutData.__init__(self, binout, logger, dynasaur_definitions, 'abstat_cpm')
+
+
 class Glstat(BinoutData):
     """
     """
@@ -1108,6 +1129,82 @@ class Nodout(BinoutData):
         BinoutData.__init__(self, data, logger, dynasaur_definitions, 'nodout')
 
 
+class JointForc(BinoutData):
+    """
+    """
+    DATA_CHANNEL_TYPES = [ 'energy', 'resultant_moment', 'resultant_force', 'x_force',  'y_force',
+                           'z_force', 'x_moment', 'y_moment', 'z_moment']
+    ids_name = "ids"
+
+    def __init__(self, data, logger, dynasaur_definitions):
+        """
+        Initialization/constructor
+
+        :param: binout
+        :param: logger
+        :param: dynasaur definition
+        :param: cody type(MADYMO/LS DYNA)
+
+        :return:
+        """
+
+        BinoutData.__init__(self, data, logger, dynasaur_definitions, 'jntforc')
+
+    def get_measurement_channel(self, id_, channel_name):
+        """
+
+        :param id:
+        :param channel_name:
+        :return:
+        """
+
+        if channel_name == 'time':
+            return self._time_interp.reshape(-1, 1)
+
+        if np.issubdtype(self._ids.dtype, np.number):
+            data_index = np.where(int(id_) == self._ids)[0]
+
+        else:  # madymo case ... ids are not numeric
+            data_index = np.where(id_ == self._ids)[0]
+
+        if len(data_index) == 0:
+            self._logger.emit(LOGConstants.ERROR[0], 'ID ' + str(id_) + ' not in binout')
+            exit()
+
+        self._logger.emit(LOGConstants.DATA_PLUGIN[0], 'read id ' + str(id_) + ' from channel name: ' + channel_name)
+        assert (len(data_index) >= 1)
+
+        if channel_name not in self._data.keys():
+            self._logger.emit(LOGConstants.ERROR[0], str(id_) + ' has no data with the identifier : ' + channel_name)
+            return []
+
+        d = self._data[channel_name][:, data_index]
+
+        return d.reshape(-1, len(data_index))
+
+        if channel_name == 'time':
+            return self._time.reshape(-1, 1)
+
+
+
+        if len(data_index) == 0:
+            self._logger.emit(LOGConstants.ERROR[0], 'ID ' + str(id_nr) + ' not in binout')
+            exit()
+        data_index = [data_index[id_slave_master]]
+
+        self._logger.emit(LOGConstants.DATA_PLUGIN[0], 'read id ' + str(id_) + ' from channel name: ' + channel_name)
+        assert (len(data_index) >= 1)
+
+        if channel_name not in self._data.keys():
+            self._logger.emit(LOGConstants.ERROR[0], str(id_) + ' has no data with the identifier : ' + channel_name)
+            return []
+
+        d = self._data[channel_name][:, data_index]
+        return d.reshape(-1, len(data_index))
+
+
+
+
 class RCForc(BinoutData):
     DATA_CHANNEL_TYPES = ['x_moment', 'y_moment', 'z_moment', 'x_force', 'y_force', 'z_force', 'tie_count', 'mass',
                           'tie_area']
