@@ -154,78 +154,80 @@ class MadymoData:
             f['MODEL_0'].visititems(self._get_available_data_types_dict)
 
             # extend the data dictionary
-            dimension = (self._d['nodout']['time'].shape[0], len(self._d['nodout']['ids']))
-            data_types_to_be_filled = [i for i in self._d['nodout'].keys() if i != "ids" and i != "time"]
-            for data_type in data_types_to_be_filled:
-                self._d['nodout'][data_type] = np.empty(dimension)
-                self._d['nodout'][data_type][:] = np.nan
+            if "nodout" in self._d:
+                dimension = (self._d['nodout']['time'].shape[0], len(self._d['nodout']['ids']))
+                data_types_to_be_filled = [i for i in self._d['nodout'].keys() if i != "ids" and i != "time"]
+                for data_type in data_types_to_be_filled:
+                    self._d['nodout'][data_type] = np.empty(dimension)
+                    self._d['nodout'][data_type][:] = np.nan
 
-                if data_type == DataChannelTypesNodout.RX_DISPLACEMENT or \
-                        data_type == DataChannelTypesNodout.RY_DISPLACEMENT or \
-                        data_type == DataChannelTypesNodout.RZ_DISPLACEMENT:
-                    idx_madymo_data = 0 if data_type == DataChannelTypesNodout.RX_DISPLACEMENT else (
-                        1 if data_type == DataChannelTypesNodout.RY_DISPLACEMENT else 2)
-                    self._extratct_data(f["MODEL_0/Angular displacements"], data_type,
-                                        idx_madymo_data=idx_madymo_data)
+                    if data_type == DataChannelTypesNodout.RX_DISPLACEMENT or \
+                            data_type == DataChannelTypesNodout.RY_DISPLACEMENT or \
+                            data_type == DataChannelTypesNodout.RZ_DISPLACEMENT:
+                        idx_madymo_data = 0 if data_type == DataChannelTypesNodout.RX_DISPLACEMENT else (
+                            1 if data_type == DataChannelTypesNodout.RY_DISPLACEMENT else 2)
+                        self._extratct_data(f["MODEL_0/Angular displacements"], data_type,
+                                            idx_madymo_data=idx_madymo_data)
 
-                elif data_type == DataChannelTypesNodout.RX_VELOCITY or \
-                        data_type == DataChannelTypesNodout.RY_VELOCITY or \
-                        data_type == DataChannelTypesNodout.RZ_VELOCITY:
-                    idx_madymo_data = 0 if data_type == DataChannelTypesNodout.RX_VELOCITY else (
-                        1 if data_type == DataChannelTypesNodout.RY_VELOCITY else 2)
-                    self._extratct_data(f["MODEL_0/Angular velocities"], data_type, idx_madymo_data=idx_madymo_data)
+                    elif data_type == DataChannelTypesNodout.RX_VELOCITY or \
+                            data_type == DataChannelTypesNodout.RY_VELOCITY or \
+                            data_type == DataChannelTypesNodout.RZ_VELOCITY:
+                        idx_madymo_data = 0 if data_type == DataChannelTypesNodout.RX_VELOCITY else (
+                            1 if data_type == DataChannelTypesNodout.RY_VELOCITY else 2)
+                        self._extratct_data(f["MODEL_0/Angular velocities"], data_type, idx_madymo_data=idx_madymo_data)
 
-                elif data_type == DataChannelTypesNodout.RX_ACCELERATION or \
-                        data_type == DataChannelTypesNodout.RY_ACCELERATION or \
-                        data_type == DataChannelTypesNodout.RZ_ACCELERATION:
-                    idx_madymo_data = 0 if data_type == DataChannelTypesNodout.RX_ACCELERATION else (
-                        1 if data_type == DataChannelTypesNodout.RY_ACCELERATION else 2)
-                    self._extratct_data(f["MODEL_0/Angular accelerations"], data_type,
-                                        idx_madymo_data=idx_madymo_data)
+                    elif data_type == DataChannelTypesNodout.RX_ACCELERATION or \
+                            data_type == DataChannelTypesNodout.RY_ACCELERATION or \
+                            data_type == DataChannelTypesNodout.RZ_ACCELERATION:
+                        idx_madymo_data = 0 if data_type == DataChannelTypesNodout.RX_ACCELERATION else (
+                            1 if data_type == DataChannelTypesNodout.RY_ACCELERATION else 2)
+                        self._extratct_data(f["MODEL_0/Angular accelerations"], data_type,
+                                            idx_madymo_data=idx_madymo_data)
 
-                elif data_type == DataChannelTypesNodout.X_ACCELERATION or \
-                        data_type == DataChannelTypesNodout.Y_ACCELERATION or \
-                        data_type == DataChannelTypesNodout.Z_ACCELERATION:
-                    idx_madymo_data = 1 if data_type == DataChannelTypesNodout.X_ACCELERATION else (
-                        2 if data_type == DataChannelTypesNodout.Y_ACCELERATION else 3)
-                    self._extratct_data(f["MODEL_0/Linear accelerations"], data_type, idx_madymo_data=idx_madymo_data)
+                    elif data_type == DataChannelTypesNodout.X_ACCELERATION or \
+                            data_type == DataChannelTypesNodout.Y_ACCELERATION or \
+                            data_type == DataChannelTypesNodout.Z_ACCELERATION:
+                        idx_madymo_data = 1 if data_type == DataChannelTypesNodout.X_ACCELERATION else (
+                            2 if data_type == DataChannelTypesNodout.Y_ACCELERATION else 3)
+                        self._extratct_data(f["MODEL_0/Linear accelerations"], data_type, idx_madymo_data=idx_madymo_data)
 
-                elif data_type == DataChannelTypesNodout.X_VELOCITY or \
-                        data_type == DataChannelTypesNodout.Y_VELOCITY or \
-                        data_type == DataChannelTypesNodout.Z_VELOCITY:
-                    idx_madymo_data = 1 if data_type == DataChannelTypesNodout.X_VELOCITY else (
-                        2 if data_type == DataChannelTypesNodout.Y_VELOCITY else 3)
-                    self._extratct_data(f["MODEL_0/Linear velocities"], data_type, idx_madymo_data=idx_madymo_data)
+                    elif data_type == DataChannelTypesNodout.X_VELOCITY or \
+                            data_type == DataChannelTypesNodout.Y_VELOCITY or \
+                            data_type == DataChannelTypesNodout.Z_VELOCITY:
+                        idx_madymo_data = 1 if data_type == DataChannelTypesNodout.X_VELOCITY else (
+                            2 if data_type == DataChannelTypesNodout.Y_VELOCITY else 3)
+                        self._extratct_data(f["MODEL_0/Linear velocities"], data_type, idx_madymo_data=idx_madymo_data)
 
-                elif data_type == DataChannelTypesNodout.X_COORDINATE or \
-                        data_type == DataChannelTypesNodout.Y_COORDINATE or \
-                        data_type == DataChannelTypesNodout.Z_COORDINATE:
-                    idx_madymo_data = 1 if data_type == DataChannelTypesNodout.X_COORDINATE else \
-                        (2 if data_type == DataChannelTypesNodout.Y_COORDINATE else 3)
-                    self._extratct_data(f["MODEL_0/Linear positions"], data_type, idx_madymo_data=idx_madymo_data)
+                    elif data_type == DataChannelTypesNodout.X_COORDINATE or \
+                            data_type == DataChannelTypesNodout.Y_COORDINATE or \
+                            data_type == DataChannelTypesNodout.Z_COORDINATE:
+                        idx_madymo_data = 1 if data_type == DataChannelTypesNodout.X_COORDINATE else \
+                            (2 if data_type == DataChannelTypesNodout.Y_COORDINATE else 3)
+                        self._extratct_data(f["MODEL_0/Linear positions"], data_type, idx_madymo_data=idx_madymo_data)
 
-                elif data_type == DataChannelTypesNodout.X_DISPLACEMENT or \
-                        data_type == DataChannelTypesNodout.Y_DISPLACEMENT or \
-                        data_type == DataChannelTypesNodout.Z_DISPLACEMENT:
-                    idx_madymo_data = 1 if data_type == DataChannelTypesNodout.X_DISPLACEMENT else (
-                        2 if data_type == DataChannelTypesNodout.Y_DISPLACEMENT else 3)
-                    self._extratct_data(f["MODEL_0/Linear displacements"], data_type, idx_madymo_data=idx_madymo_data)
+                    elif data_type == DataChannelTypesNodout.X_DISPLACEMENT or \
+                            data_type == DataChannelTypesNodout.Y_DISPLACEMENT or \
+                            data_type == DataChannelTypesNodout.Z_DISPLACEMENT:
+                        idx_madymo_data = 1 if data_type == DataChannelTypesNodout.X_DISPLACEMENT else (
+                            2 if data_type == DataChannelTypesNodout.Y_DISPLACEMENT else 3)
+                        self._extratct_data(f["MODEL_0/Linear displacements"], data_type, idx_madymo_data=idx_madymo_data)
 
-            dimension = (self._d['matsum']['time'].shape[0], len(self._d['matsum']['ids']))
-            energy_to_be_filled = [i for i in self._d['matsum'].keys() if i != "ids" and i != "time"]
-            for energy_type in energy_to_be_filled:
-                self._d['matsum'][energy_type] = np.empty(dimension)
-                self._d['matsum'][energy_type][:] = np.nan
-                self._extract_data_energy(f["MODEL_0/Energy output"], 'matsum', self._d["matsum"]["ids"], energy_type)
+            if "matsum" in self._d:
+                dimension = (self._d['matsum']['time'].shape[0], len(self._d['matsum']['ids']))
+                energy_to_be_filled = [i for i in self._d['matsum'].keys() if i != "ids" and i != "time"]
+                for energy_type in energy_to_be_filled:
+                    self._d['matsum'][energy_type] = np.empty(dimension)
+                    self._d['matsum'][energy_type][:] = np.nan
+                    self._extract_data_energy(f["MODEL_0/Energy output"], 'matsum', self._d["matsum"]["ids"], energy_type)
 
-            dimension = (self._d['glstat']['time'].shape[0],len(self._d['glstat']['ids']))
-            energy_to_be_filled = [i for i in self._d['glstat'].keys() if i != "ids" and i != "time"]
-            for energy_type in energy_to_be_filled:
-                self._d['glstat'][energy_type] = np.empty(dimension)
-                self._d['glstat'][energy_type][:] = np.nan
-                self._extract_data_energy(f["MODEL_0/Energy output"], 'glstat', self._d["glstat"]["ids"], energy_type)
-                self._d["glstat"][energy_type] = self._d["glstat"][energy_type].flatten()
-                a = 0
+            if "glstat" in self._d:
+                dimension = (self._d['glstat']['time'].shape[0],len(self._d['glstat']['ids']))
+                energy_to_be_filled = [i for i in self._d['glstat'].keys() if i != "ids" and i != "time"]
+                for energy_type in energy_to_be_filled:
+                    self._d['glstat'][energy_type] = np.empty(dimension)
+                    self._d['glstat'][energy_type][:] = np.nan
+                    self._extract_data_energy(f["MODEL_0/Energy output"], 'glstat', self._d["glstat"]["ids"], energy_type)
+                    self._d["glstat"][energy_type] = self._d["glstat"][energy_type].flatten()
 
         logger = ConsoleLogger()
         self.dynasaur_definitions = DynasaurDefinitions(logger)
