@@ -25,7 +25,6 @@ class CriteriaController(Plugin, PluginInterface):
                         data_source=data_source, volume_path=volume_def_file, user_function_object=user_function_object,
                         name=DefinitionConstants.CRITERIA, code_type=code_type)
 
-
         # self._data_source = data_source
         self.init_plugin_data(update=True)
         self._data_dict = {}
@@ -44,7 +43,11 @@ class CriteriaController(Plugin, PluginInterface):
         json_object = param_dict[PluginsParamDictDef.DYNASAUR_JSON]
         reduced_sample_offsets = self._reduce_sample_offset(json_object, sample_offset)
 
-        assert all([off == sample_offset[0][1] for i, off, _ in sample_offset])
+        if not all([off == sample_offset[0][1] for i, off, _ in sample_offset]):
+            required_data = [data_type for data_type, _, _ in sample_offset]
+            self._logger.emit(LOGConstants.ERROR[0],
+                              "Required data " + str(required_data) + " has not the same sampling frequency.")
+            return
 
         ret = self._get_data_from_dynasaur_json(json_object, reduced_sample_offsets)
         ret_tuple = ret if isinstance(ret, tuple) else (ret, '-')
@@ -74,8 +77,8 @@ class CriteriaController(Plugin, PluginInterface):
                                                                        {OutputStringForPlugins.VALUE: value}})
             else:
                 self._data_dict[part_of][type_of_criteria].update({criteria_name:
-                                                           {OutputStringForPlugins.VALUE: value,
-                                                            OutputStringForPlugins.LIMITS: limits}})
+                                                                       {OutputStringForPlugins.VALUE: value,
+                                                                        OutputStringForPlugins.LIMITS: limits}})
 
     def write_CSV(self, directory, filename=None):
         """
@@ -99,7 +102,8 @@ class CriteriaController(Plugin, PluginInterface):
                 for criteria_name in self._data_dict[part_of][criteria_type].keys():
                     if OutputStringForPlugins.LIMITS in self._data_dict[part_of][criteria_type][criteria_name]:
                         rows.append(part_of + ":" + criteria_type + ":" + criteria_name + ":" +
-                            self._data_dict[part_of][criteria_type][criteria_name][OutputStringForPlugins.LIMITS])
+                                    self._data_dict[part_of][criteria_type][criteria_name][
+                                        OutputStringForPlugins.LIMITS])
                     else:
                         rows.append(part_of + ":" + criteria_type + ":" + criteria_name)
 
@@ -135,7 +139,7 @@ class CriteriaController(Plugin, PluginInterface):
                 for counter, criteria_t in enumerate(self._data_dict[parts_of].keys()):
                     if criteria_name not in self._data_dict[parts_of][criteria_t]:
                         if counter == len(self._data_dict[parts_of].keys()) - 1 \
-                                and counter_one == len(self._data_dict.keys()) - 1\
+                                and counter_one == len(self._data_dict.keys()) - 1 \
                                 and len(return_dict) == 0:
                             self._logger.emit(LOGConstants.ERROR[0], criteria_name + " not in data dictionary")
                             return
