@@ -1,6 +1,6 @@
 from termcolor import colored
-
 from ..utils.constants import LOGConstants
+import colorama
 
 
 class ConsoleLogger(object):
@@ -10,6 +10,7 @@ class ConsoleLogger(object):
         :param:
         :return:
         """
+        colorama.init()
         pass
 
     def _get_color_for_label(self, label):
